//////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
//include Qreflnd includes
include <qreflnd.wdl>;  //camera view

var video_mode = 6; // 800x600
var video_depth = 16; // 16 bit mode

var game_started = 0; // will be set to 1 when the game is started
var sound_vol = 70; // default sound value at game start; sound_vol is an engine variable
var video_value = 7; // default resolution at game start (800x600)

//////////////////////////////////////////////////////////////////////////

bmap main_pcx = <main.pcx>; // main panel
bmap new1_pcx = <new1.pcx>;
bmap new2_pcx = <new2.pcx>;
bmap sound1_pcx = <sound1.pcx>;
bmap sound2_pcx = <sound2.pcx>;
bmap video1_pcx = <video1.pcx>;
bmap video2_pcx = <video2.pcx>;
bmap quit1_pcx = <quit1.pcx>;
bmap quit2_pcx = <quit2.pcx>;
bmap maincursor_pcx = <maincurs.pcx>;

bmap sound_pcx = <sound.pcx>; // sound volume panel
bmap video_pcx = <video.pcx>; // video resolution panel
bmap slider_pcx = <slider.pcx>;

//////////////////////////////////////////////////////////////////////////

sound mouse_snd = <mousesnd.wav>;

//////////////////////////////////////////////////////////////////////////
string level_str = <Qreflnd.wmb>; // give file names in angular brackets
//string introlevel_wmb = <introlev.wmb>;
string level1_wmb = <level1.wmb>;

/////////////////////////////////////////////////////////////////////////

function game_init();
function mouse_over();
function mainmenu_mouse();
function start_game();
function set_volume();
function set_resolution();
function quit_game();
/////////////////////////////////////////////////////////////////////

panel main_pan // main panel
{
	bmap = main_pcx;
	layer = 20;
	pos_x = 220; // for now
	pos_y = 200; // for now
	button = 50, 65, new1_pcx, new1_pcx, new2_pcx, null, start_game, mouse_over;
	button = 50, 115, sound1_pcx, sound1_pcx, sound2_pcx, null, set_volume, mouse_over;	
	button = 50, 165, video1_pcx, video1_pcx, video2_pcx, null, set_resolution, mouse_over;	
	button = 50, 215, quit1_pcx, quit1_pcx, quit2_pcx, null, quit_game, mouse_over;	
	flags = d3d, overlay, refresh;	
}

panel sound_pan // sound panel
{
	bmap = sound_pcx;
	layer = 20;
	pos_x = 160; // for now
	pos_y = 240; // for now
	hslider = 60, 95, 200, slider_pcx, 0, 100, sound_vol;	
	flags = d3d, overlay, refresh;	
}

panel video_pan // video resolution panel
{
	bmap = video_pcx;
	layer = 20;
	pos_x = 160; // for now
	pos_y = 240; // for now
	hslider = 60, 95, 200, slider_pcx, 4, 8, video_value;	
	flags = d3d, overlay, refresh;	
}

function main()
{
        
	on_esc = null; // don't exit the engine by Escape (default)
	level_load (level1_wmb); // dummy level
	wait (2);
	game_init(); // checks the Esc key state and changes the panels if needed 
	main_pan.visible = on; // show the main panel
	mainmenu_mouse(); // and give me a cursor to play with
	vec_set (camera.pos, nullvector); // move camera to the origin
	while (game_started == 0) // we haven't pressed New yet
	{
		camera.pan += 0.3 * time; // rotate the camera gently
		camera.tilt += 0.1 * time;
		camera.roll += 0.05 * time;
		wait (1);
	}
	
	
}	

action eye_checker // attached to the sprite
{
	my.oriented = on;
}

function mouse_over() // is executed when we are over the menu buttons
{
	play_sound (mouse_snd, 70);
}	

function mainmenu_mouse () // displays the cursor in main menu
{
	mouse_mode = 2;
	mouse_map = maincursor_pcx;
	while (game_started == 0) // we haven't started the game yet
	{
		mouse_pos.x = pointer.x;
		mouse_pos.y = pointer.y;
		wait (1); 		      
	}   
}

function start_game()
{
	main_pan.visible = off;
	game_started = 1;
	mouse_mode = 0; // hide the cursor
	level_load(level_str);
	wait (2);
	//camera.z = 220;
	//camera.tilt = -90; // camera looks down
}

function set_volume() // shows the sound panel
{
	main_pan.visible = off;
	sound_pan.visible = on;
}

function set_resolution() // shows the video panel
{
	main_pan.visible = off;
	video_pan.visible = on;
}

function quit_game()
{
	exit;
}

function game_init() // checks the Esc state and changes the panels accordingly
{
	while (1)
	{
		// first of all, calculate pos_x and pos_y for all the panels
		// to make sure that they are centered at any resolution
		main_pan.pos_x = (screen_size.x - bmap_width(main_pcx)) / 2;
		main_pan.pos_y = (screen_size.y - bmap_height(main_pcx)) / 2;
		sound_pan.pos_x = (screen_size.x - bmap_width(sound_pcx)) / 2;
		sound_pan.pos_y = (screen_size.y - bmap_height(sound_pcx)) / 2;
		video_pan.pos_x = (screen_size.x - bmap_width(video_pcx)) / 2;
		video_pan.pos_y = (screen_size.y - bmap_height(video_pcx)) / 2;
		if (key_esc == 1)
		{
			while (key_esc == 1) {wait (1);} // wait for release
			if (main_pan.visible == on) 
			{
				main_pan.visible = off;
				mouse_mode = 0; // hide the cursor
			}
			else // main_pan isn't visible
			{
				if (sound_pan.visible == off && video_pan.visible == off)
				{
					main_pan.visible = on;
					game_started = 0;	// stop the game
					mainmenu_mouse(); // show the cursor
				}
			}
			if (sound_pan.visible == on)
			{
				sound_pan.visible = off;
				main_pan.visible = on;	
			}
			if (video_pan.visible == on)
			{
				video_pan.visible = off;
				main_pan.visible = on;	
				if (int (video_value != video_mode)) // resolution has changed
				{
					switch_video (video_value, 16, 1);
				}
			}
		}
		wait (1);
	}			
}

